@@ -146,12 +146,12 @@
        (udecl (cdar (unitize-decl (sx-ref tree 1) '())))
        (mdecl (udecl->mdecl udecl))
        )
-  ;;(pp tree)
+  (pp tree)
   ;;(pp udict)
   ;;(pp rdecl)
-  (pp udecl)
-  (pp mdecl)
-  (pp (mdecl->udecl mdecl))
+  ;;(pp udecl)
+  ;;(pp mdecl)
+  ;;(pp (mdecl->udecl mdecl))
   ;;(pp99 (cdar udecl))
   ;;(pp mdecl)
   ;;(pp xdecl)
