@@ -20,11 +20,15 @@
 ;; This is a JavaScript parser for Guile.
 
 (define-module (nyacc lang javascript parser)
-  #:export (parse-js js-stmt-reader js-file-reader)
+  #:export (parse-js read-js-stmt read-js-file)
   #:use-module (nyacc lex)
   #:use-module (nyacc parse)
   #:use-module (nyacc lang sx-util)
   #:use-module (nyacc lang util))
+(define (sferr fmt . args) (apply simple-format (current-error-port) fmt args))
+(use-modules (ice-9 pretty-print))
+(define (pperr exp)
+  (pretty-print exp (current-error-port) #:per-line-prefix "  "))
 
 (include-from-path "nyacc/lang/javascript/body.scm")
 
@@ -50,16 +54,28 @@
       (apply simple-format (current-error-port) fmt rest)
       #f)))
 
-;; @deffn {Procedure} js-file-reader port env => sxml
+;; @deffn {Procedure} read-js-file port env => sxml
 ;; Read file unit from port and return SXML AST.
 ;; @end deffn
-(define (js-file-reader port env)
+(define (read-js-file port env)
   (if (eof-object? (peek-char port))
       (read-char port)
       (with-input-from-port port parse-js)))
 
 ;; === interactive parser =============
 
+;; If a syntax error is detected by the reader then we usually want to flush
+;; input until an end of statement is seen.  And return #f
+(define flush-input-after-error
+  (let ((read-string (make-string-reader #\")))
+    (lambda (port)
+      (let loop ((ch (read-char port)))
+	(cond
+	 ((eqv? ch #\;) #f)
+	 ((read-js-string ch) (loop (read-char port)))
+	 ((read-c-comm ch #t) #f)
+	 (else (loop (read-char port))))))))
+
 (include-from-path "nyacc/lang/javascript/mach.d/ia-js-tab.scm")
 (include-from-path "nyacc/lang/javascript/mach.d/ia-js-act.scm")
 
@@ -81,20 +97,9 @@
     (lambda (key fmt . rest)
       (apply simple-format (current-error-port) fmt rest)
       #f)))
+(export parse-js-stmt)
 
-;; If a syntax error is detected by the reader then we usually want to flush
-;; input until an end of statement is seen.  And return #f
-(define flush-input-after-error
-  (let ((read-string (make-string-reader #\")))
-    (lambda (port)
-      (let loop ((ch (read-char port)))
-	(cond
-	 ((eqv? ch #\;) #f)
-	 ((read-js-string ch) (loop (read-char port)))
-	 ((read-c-comm ch #t) #f)
-	 (else (loop (read-char port))))))))
-
-(define (js-stmt-reader port env)
+(define (read-js-stmt port env)
   (if (eof-object? (peek-char port))
       (read-char port)
       (let ((elt (with-input-from-port port parse-js-stmt)))
