@@ -20,15 +20,13 @@
 (define-module (nyacc export)
   #:export (lalr->bison
 	    lalr->guile
-	    c-char token->bison elt->bison
-	    )
+	    c-char token->bison elt->bison)
   #:use-module ((nyacc lalr) #:select (find-terminal pp-rule lalr-start))
   #:use-module (nyacc lex)
   #:use-module (nyacc util)
   #:use-module ((srfi srfi-1) #:select (fold))
   #:use-module ((srfi srfi-43) #:select (vector-for-each))
-  #:use-module (ice-9 regex)
-  )
+  #:use-module (ice-9 regex))
 
 ;; The code below, for exporting to guile and bison, should be moved to
 ;; an "export" module.
@@ -118,17 +116,17 @@
 	 (fmt port "%token ~A\n" (token->bison term))))
      terms)
     ;; Write the associativity and prececences.
-    (let iter ((pl '()) (ppl (assq-ref spec 'prec)))
+    (let loop ((pl '()) (ppl (assq-ref spec 'prec)))
       (cond
        ((pair? pl)
 	(fmt port "%~A" (or (assq-ref assc (caar pl)) "precedence"))
-	(let iter2 ((pl (car pl)))
+	(let loop2 ((pl (car pl)))
 	  (unless (null? pl)
 	    (fmt port " ~A" (elt->bison (car pl) terms))
-	    (iter2 (cdr pl))))
+	    (loop2 (cdr pl))))
 	(fmt port "\n")
-	(iter (cdr pl) ppl))
-       ((pair? ppl) (iter (car ppl) (cdr ppl)))))
+	(loop (cdr pl) ppl))
+       ((pair? ppl) (loop (car ppl) (cdr ppl)))))
     ;; Don't compact tables.
     (fmt port "%define lr.default-reduction accepting\n")
     ;; Provide start symbol.
@@ -189,8 +187,7 @@
 		   (cond
 		    ((equal? #\; e) (fmtstr "C-semi"))
 		    ((char? e) (fmtstr "C-~A" e))
-		    (else e)))
-		  ))
+		    (else e)))))
 	      (fmt port ") ")
 	      (fmt port ": ~S" `(begin ,@(vector-ref act-v i)))
 	      (fmt port "\n")
