@@ -246,6 +246,8 @@
    (lambda ($1 . $rest) `(type-spec ,$1))
    ;; type-specifier => float-type-specifier
    (lambda ($1 . $rest) `(type-spec ,$1))
+   ;; type-specifier => fixpt-type-specifier
+   (lambda ($1 . $rest) `(type-spec ,$1))
    ;; type-specifier => "_Bool"
    (lambda ($1 . $rest)
      '(type-spec (fixed-type "_Bool")))
@@ -346,6 +348,111 @@
    ;; complex-type-specifier => "long" "double" "_Complex"
    (lambda ($3 $2 $1 . $rest)
      '(complex-type "long double _Complex"))
+   ;; fixpt-type-specifier => "short" "_Fract"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "short _Fract"))
+   ;; fixpt-type-specifier => "_Fract"
+   (lambda ($1 . $rest) '(fixpt-type "_Fract"))
+   ;; fixpt-type-specifier => "long" "_Fract"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "long _Fract"))
+   ;; fixpt-type-specifier => "signed" "short" "_Fract"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "signd short _Fract"))
+   ;; fixpt-type-specifier => "signed" "_Fract"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "signed _Fract"))
+   ;; fixpt-type-specifier => "signed" "long _Fract"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "signed long _Fract"))
+   ;; fixpt-type-specifier => "unsigned" "short" "_Fract"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "unsigned short _Fract"))
+   ;; fixpt-type-specifier => "unsigned" "_Fract"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "unsigned _Fract"))
+   ;; fixpt-type-specifier => "unsigned" "long _Fract"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "unsigned long _Fract"))
+   ;; fixpt-type-specifier => "short" "_Accum"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "short _Accum"))
+   ;; fixpt-type-specifier => "_Accum"
+   (lambda ($1 . $rest) '(fixpt-type "_Accum"))
+   ;; fixpt-type-specifier => "long _Accum"
+   (lambda ($1 . $rest) '(fixpt-type "long _Accum"))
+   ;; fixpt-type-specifier => "signed" "short" "_Accum"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "signd short _Accum"))
+   ;; fixpt-type-specifier => "signed" "_Accum"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "signed _Accum"))
+   ;; fixpt-type-specifier => "signed" "long" "_Accum"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "signed long _Accum"))
+   ;; fixpt-type-specifier => "unsigned" "short" "_Accum"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "unsigned short _Accum"))
+   ;; fixpt-type-specifier => "unsigned" "_Accum"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "unsigned _Accum"))
+   ;; fixpt-type-specifier => "unsigned" "long" "_Accum"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "unsigned long _Accum"))
+   ;; fixpt-type-specifier => "_Sat" "short" "_Fract"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "_Sat short _Fract"))
+   ;; fixpt-type-specifier => "_Sat" "_Fract"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "_Sat _Fract"))
+   ;; fixpt-type-specifier => "_Sat" "long" "_Fract"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "_Sat long _Fract"))
+   ;; fixpt-type-specifier => "_Sat" "signed" "short" "_Fract"
+   (lambda ($4 $3 $2 $1 . $rest)
+     '(fixpt-type "_Sat signd short _Fract"))
+   ;; fixpt-type-specifier => "_Sat" "signed" "_Fract"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "_Sat signed _Fract"))
+   ;; fixpt-type-specifier => "_Sat" "signed" "long _Fract"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "_Sat signed long _Fract"))
+   ;; fixpt-type-specifier => "_Sat" "unsigned" "short" "_Fract"
+   (lambda ($4 $3 $2 $1 . $rest)
+     '(fixpt-type "_Sat unsigned short _Fract"))
+   ;; fixpt-type-specifier => "_Sat" "unsigned" "_Fract"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "_Sat unsigned _Fract"))
+   ;; fixpt-type-specifier => "_Sat" "unsigned" "long" "_Fract"
+   (lambda ($4 $3 $2 $1 . $rest)
+     '(fixpt-type "_Sat unsigned long _Fract"))
+   ;; fixpt-type-specifier => "_Sat" "short" "_Accum"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "_Sat short _Accum"))
+   ;; fixpt-type-specifier => "_Sat" "_Accum"
+   (lambda ($2 $1 . $rest)
+     '(fixpt-type "_Sat _Accum"))
+   ;; fixpt-type-specifier => "_Sat" "long" "_Accum"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "_Sat long _Accum"))
+   ;; fixpt-type-specifier => "_Sat" "signed" "short" "_Accum"
+   (lambda ($4 $3 $2 $1 . $rest)
+     '(fixpt-type "_Sat signd short _Accum"))
+   ;; fixpt-type-specifier => "_Sat" "signed" "_Accum"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "_Sat signed _Accum"))
+   ;; fixpt-type-specifier => "_Sat" "signed" "long" "_Accum"
+   (lambda ($4 $3 $2 $1 . $rest)
+     '(fixpt-type "_Sat signed long _Accum"))
+   ;; fixpt-type-specifier => "_Sat" "unsigned" "short" "_Accum"
+   (lambda ($4 $3 $2 $1 . $rest)
+     '(fixpt-type "_Sat unsigned short _Accum"))
+   ;; fixpt-type-specifier => "_Sat" "unsigned" "_Accum"
+   (lambda ($3 $2 $1 . $rest)
+     '(fixpt-type "_Sat unsigned _Accum"))
+   ;; fixpt-type-specifier => "_Sat" "unsigned" "long" "_Accum"
+   (lambda ($4 $3 $2 $1 . $rest)
+     '(fixpt-type "_Sat unsigned long _Accum"))
    ;; struct-or-union-specifier => "struct" opt-attr-specs ident-like "{" s...
    (lambda ($6 $5 $4 $3 $2 $1 . $rest)
      (sx-join* 'struct-def $2 $3 (tl->list $5)))
@@ -506,6 +613,9 @@
    ;; attribute => attr-word "(" attr-expr-list ")"
    (lambda ($4 $3 $2 $1 . $rest)
      `(attribute ,$1 ,$3))
+   ;; attribute => "const"
+   (lambda ($1 . $rest)
+     `(attribute (ident "const")))
    ;; attr-word => attr-name
    (lambda ($1 . $rest) $1)
    ;; attr-word => identifier
